import type { DialogSetting } from '@/types/table'
import type { FormInstance } from 'element-plus'
import { useRequest } from './useRequest'
import axiosInstance from '@/utils/axios/axiosInstance'
import { ElMessage } from 'element-plus'
import { nextTick } from 'vue'
import 'element-plus/theme-chalk/el-message.css'
import 'element-plus/theme-chalk/el-message-box.css'

export function useDialog() {
  const { analysisResCode } = useRequest()

  // 对话框关闭
  const dialogClose = (formEl: FormInstance | undefined, dialogConfig: DialogSetting) => {
    if (!formEl) return
    console.log('asdas')
    dialogConfig.dialogVisible = false
    formEl.resetFields()
  }

  // 对话框提交
  const submitDialog = (
    formEl: FormInstance | undefined,
    dialogConfig: DialogSetting,
    url: string,
    formData: any
  ) => {
    return new Promise((reslove, reject) => {
      try {
        if (!formEl) {
          reject(new Error('no formEl'))
          return
        }
        formEl.validate(async (valid, field) => {
          if (valid) {
            let result = await axiosInstance.post(url, formData)
            let info = JSON.parse(JSON.stringify(result))

            analysisResCode(info)
              .then(() => {
                dialogConfig.dialogVisible = false
                reslove(true)
              })
              .catch((err) => {
                reject(err)
                console.log(err)
              })
          } else {
            console.log(field)
            console.log('表单校验不通过')
          }
        })
      } catch (err) {
        console.log(err)
        ElMessage({
          type: 'error',
          message: '未知错误'
        })
        throw new Error('other err')
      }
    })
  }

  // 修改按钮
  const handleEdit = (row: any, formData: any, dialogConfig: DialogSetting) => {
    dialogConfig.type = 1
    dialogConfig.dialogVisible = true

    // 这里放到nextTick，因为resetFields原理是将表单重置到dom刚渲染时的数据
    // 而这个表单，如果第一次使用就点击编辑的话，会将初始值直接设置为这行的数据，导致无法重置
    nextTick(() => {
      for (const key in row) {
        if (key in formData) {
          formData[key] = row[key]
        } else {
          console.log(key)
        }
      }
    })
  }

  const addNeweItem = (dialogConfig: DialogSetting) => {
    dialogConfig.type = 0
    dialogConfig.dialogVisible = true
  }

  return {
    dialogClose,
    submitDialog,
    handleEdit,
    addNeweItem
  }
}
